MethodChannelAndroidLogTransport class

MethodChannel-based implementation of AndroidLogTransportPlatform.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

log(Map<String, dynamic> event) → Future<void>
Sends event to Android Logcat via the platform channel.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited